@@ -1,5 +1,5 @@
 
-// $Id: common.h 175 2009-01-25 13:33:01Z jessekornblum $ 
+// $Id: common.h 227 2010-03-06 14:46:36Z jessekornblum $ 
 
 #ifndef __COMMON_H
 #define __COMMON_H
@@ -13,7 +13,6 @@
 # define __MSVCRT_VERSION__ 0x0601
 #endif
 
-
 // The version information, VERSION, is defined in config.h 
 
 #define AUTHOR      "Jesse Kornblum"
@@ -130,6 +129,9 @@ NEWLINE, NEWLINE, NEWLINE
 
 #define MAX_TIME_STRING_LENGTH  31
 
+// This denotes when we don't know the file size.
+#define UNKNOWN_FILE_SIZE  -1
+
 // LINE_LENGTH is different between UNIX and WIN32 and is defined below 
 #define MAX_FILENAME_LENGTH   LINE_LENGTH - 41
 
@@ -263,8 +265,9 @@ memset(VAR,0,SIZE * sizeof(TYPE));
 #define mode_timestamp         1<<21
 #define mode_csv               1<<22
 
+#define mode_read_from_file    1<<25
 
-// Modes 23-48 are reserved for future use.
+// Modes 26-48 are reserved for future use.
 //
 // Note that the LL is required to avoid overflows of 32-bit words.
 // LL must be used for any value equal to or above 1<<31. 
@@ -289,7 +292,8 @@ memset(VAR,0,SIZE * sizeof(TYPE));
 
 
 // These are the types of files we can encounter while hashing 
-
+// Note these will be stored in a uint8_t, so should be between
+// zero and 255.
 #define stat_regular    0
 #define stat_directory  1
 #define stat_door       2
@@ -337,6 +341,8 @@ int done_processing_dir(TCHAR *fn);
 // ------------------------------------------------------------------
 // HELPER FUNCTIONS
 // ------------------------------------------------------------------ 
+void setup_expert_mode(state *s, char *arg);
+
 void generate_filename(state *s, TCHAR *fn, TCHAR *cwd, TCHAR *input);
 
 uint64_t find_block_size(state *s, char *input_str);
